pub struct AccountToChannelsConnection {
pub count: i64,
pub page_info: PageInfo,
pub entities: Vec<Channel>,
pub typename: String,
}Fields
count: i64The total count of objects in this connection, using the current filters. It is different from the number of objects returned in the current page (in the entities field).
page_info: PageInfoAn object that holds pagination information about the objects in this connection.
entities: Vec<Channel>The channels for the current page of this connection.
typename: StringThe typename of the object