pub struct ChannelSnapshot {
pub id: String,
pub created_at: DateTime<Utc>,
pub updated_at: DateTime<Utc>,
pub local_balance: Option<CurrencyAmount>,
pub local_unsettled_balance: Option<CurrencyAmount>,
pub remote_balance: Option<CurrencyAmount>,
pub remote_unsettled_balance: Option<CurrencyAmount>,
pub status: Option<String>,
pub channel: EntityWrapper,
pub local_channel_reserve: Option<CurrencyAmount>,
pub timestamp: DateTime<Utc>,
pub typename: String,
}Fields
id: StringThe unique identifier of this entity across all Lightspark systems. Should be treated as an opaque string.
created_at: DateTime<Utc>The date and time when the entity was first created.
updated_at: DateTime<Utc>The date and time when the entity was last updated.
local_balance: Option<CurrencyAmount>local_unsettled_balance: Option<CurrencyAmount>remote_balance: Option<CurrencyAmount>remote_unsettled_balance: Option<CurrencyAmount>status: Option<String>channel: EntityWrapperlocal_channel_reserve: Option<CurrencyAmount>timestamp: DateTime<Utc>The timestamp that was used to query the snapshot of the channel
typename: StringThe typename of the object