ChannelStatus

Enum ChannelStatus 

pub enum ChannelStatus {
    Ok,
    Pending,
    Offline,
    UnbalancedForSend,
    UnbalancedForReceive,
    Closed,
    Error,
}
This is an enum representing the status of a channel on the Lightning Network.

Variants



Ok

The channel is online and ready to send and receive funds.



Pending

The channel has been created, but the Bitcoin transaction that initiates it still needs to be confirmed on the Bitcoin blockchain.



Offline

The channel is not available, likely because the peer is not online.



UnbalancedForSend

The channel is behaving properly, but its remote balance is much higher than its local balance so it is not balanced properly for sending funds out.



UnbalancedForReceive

The channel is behaving properly, but its remote balance is much lower than its local balance so it is not balanced properly for receiving funds.



Closed

The channel has been closed. Information about the channel is still available for historical purposes but the channel cannot be used anymore.



Error

Something unexpected happened and we cannot determine the status of this channel. Please try again later or contact the support.