Node

Trait Node 

pub trait Node: Entity {
    // Required methods
    fn get_alias(&self) -> Option<String>;
    fn get_bitcoin_network(&self) -> BitcoinNetwork;
    fn get_color(&self) -> Option<String>;
    fn get_conductivity(&self) -> Option<i64>;
    fn get_display_name(&self) -> String;
    fn get_public_key(&self) -> Option<String>;
    fn type_name(&self) -> &'static str;
}

Required Methods

fn get_alias(&self) -> Option<String>

A name that identifies the node. It has no importance in terms of operating the node, it is just a way to identify and search for commercial services or popular nodes. This alias can be changed at any time by the node operator.

fn get_bitcoin_network(&self) -> BitcoinNetwork

The Bitcoin Network this node is deployed in.

fn get_color(&self) -> Option<String>

A hexadecimal string that describes a color. For example “#000000” is black, “#FFFFFF” is white. It has no importance in terms of operating the node, it is just a way to visually differentiate nodes. That color can be changed at any time by the node operator.

fn get_conductivity(&self) -> Option<i64>

A summary metric used to capture how well positioned a node is to send, receive, or route transactions efficiently. Maximizing a node’s conductivity helps a node’s transactions to be capital efficient. The value is an integer ranging between 0 and 10 (bounds included).

fn get_display_name(&self) -> String

The name of this node in the network. It will be the most human-readable option possible, depending on the data available for this node.

fn get_public_key(&self) -> Option<String>

The public key of this node. It acts as a unique identifier of this node in the Lightning Network.

fn type_name(&self) -> &'static str

Implementors