pub struct PostTransactionData {
pub utxo: String,
pub amount: CurrencyAmount,
}Expand description
This object represents post-transaction data that could be used to register payment for KYT.
Fields
utxo: StringThe utxo of the channel over which the payment went through in the format of <transaction_hash>:<output_index>.
amount: CurrencyAmountThe amount of funds transferred in the payment.