RegionCode

Enum RegionCode 

pub enum RegionCode {
Show 250 variants Af, Ax, Al, Dz, As, Ad, Ao, Ai, Aq, Ag, Ar, Am, Aw, Au, At, Az, Bs, Bh, Bd, Bb, By, Be, Bz, Bj, Bm, Bt, Bo, Bq, Ba, Bw, Bv, Br, Io, Bn, Bg, Bf, Bi, Kh, Cm, Ca, Cv, Ky, Cf, Td, Cl, Cn, Cx, Cc, Co, Km, Cg, Cd, Ck, Cr, Ci, Hr, Cu, Cw, Cy, Cz, Dk, Dj, Dm, Do, Ec, Eg, Sv, Gq, Er, Ee, Et, Fk, Fo, Fj, Fi, Fr, Gf, Pf, Tf, Ga, Gm, Ge, De, Gh, Gi, Gr, Gl, Gd, Gp, Gu, Gt, Gg, Gn, Gw, Gy, Ht, Hm, Va, Hn, Hk, Hu, Is, In, Id, Ir, Iq, Ie, Im, Il, It, Jm, Jp, Je, Jo, Kz, Ke, Ki, Kp, Kr, Kw, Kg, La, Lv, Lb, Ls, Lr, Ly, Li, Lt, Lu, Mo, Mk, Mg, Mw, My, Mv, Ml, Mt, Mh, Mq, Mr, Mu, Yt, Mx, Fm, Md, Mc, Mn, Me, Ms, Ma, Mz, Mm, Na, Nr, Np, Nl, Nc, Nz, Ni, Ne, Ng, Nu, Nf, Mp, No, Om, Pk, Pw, Ps, Pa, Pg, Py, Pe, Ph, Pn, Pl, Pt, Pr, Qa, Re, Ro, Ru, Rw, Bl, Sh, Kn, Lc, Mf, Pm, Vc, Ws, Sm, St, Sa, Sn, Rs, Sc, Sl, Sg, Sx, Sk, Si, Sb, So, Za, Gs, Ss, Es, Lk, Sd, Sr, Sj, Sz, Se, Ch, Sy, Tw, Tj, Tz, Th, Tl, Tg, Tk, To, Tt, Tn, Tr, Tm, Tc, Tv, Ug, Ua, Ae, Gb, Us, Um, Uy, Uz, Vu, Ve, Vn, Vg, Vi, Wf, Eh, Ye, Zm, Zw, Nn,
}
The alpha-2 representation of a country, as defined by the ISO 3166-1 standard.

Variants



Af

The code representing the country of Afghanistan.



Ax

The code representing the country of Åland Islands.



Al

The code representing the country of Albania.



Dz

The code representing the country of Algeria.



As

The code representing the country of American Samoa.



Ad

The code representing the country of Andorra.



Ao

The code representing the country of Angola.



Ai

The code representing the country of Anguilla.



Aq

The code representing the country of Antarctica.



Ag

The code representing the country of Antigua and Barbuda.



Ar

The code representing the country of Argentina.



Am

The code representing the country of Armenia.



Aw

The code representing the country of Aruba.



Au

The code representing the country of Australia.



At

The code representing the country of Austria.



Az

The code representing the country of Azerbaijan.



Bs

The code representing the country of Bahamas.



Bh

The code representing the country of Bahrain.



Bd

The code representing the country of Bangladesh.



Bb

The code representing the country of Barbados.



By

The code representing the country of Belarus.



Be

The code representing the country of Belgium.



Bz

The code representing the country of Belize.



Bj

The code representing the country of Benin.



Bm

The code representing the country of Bermuda.



Bt

The code representing the country of Bhutan.



Bo

The code representing the country of The Plurinational State of Bolivia.



Bq

The code representing the country of Bonaire, Sint Eustatius, and Saba.



Ba

The code representing the country of Bosnia and Herzegovina.



Bw

The code representing the country of Botswana.



Bv

The code representing the country of Bouvet Island.



Br

The code representing the country of Brazil.



Io

The code representing the country of British Indian Ocean Territory.



Bn

The code representing the country of Brunei Darussalam.



Bg

The code representing the country of Bulgaria.



Bf

The code representing the country of Burkina Faso.



Bi

The code representing the country of Burundi.



Kh

The code representing the country of Cambodia.



Cm

The code representing the country of Cameroon.



Ca

The code representing the country of Canada.



Cv

The code representing the country of Cape Verde.



Ky

The code representing the country of Cayman Islands.



Cf

The code representing the country of Central African Republic.



Td

The code representing the country of Chad.



Cl

The code representing the country of Chile.



Cn

The code representing the country of China.



Cx

The code representing the country of Christmas Island.



Cc

The code representing the country of Cocos (Keeling) Islands.



Co

The code representing the country of Colombia.



Km

The code representing the country of Comoros.



Cg

The code representing the country of Congo.



Cd

The code representing the country of The Democratic Republic of the Congo.



Ck

The code representing the country of Cook Islands.



Cr

The code representing the country of Costa Rica.



Ci

The code representing the country of Côte d’Ivoire.



Hr

The code representing the country of Croatia.



Cu

The code representing the country of Cuba.



Cw

The code representing the country of Curaçao.



Cy

The code representing the country of Cyprus.



Cz

The code representing the country of Czech Republic.



Dk

The code representing the country of Denmark.



Dj

The code representing the country of Djibouti.



Dm

The code representing the country of Dominica.



Do

The code representing the country of Dominican Republic.



Ec

The code representing the country of Ecuador.



Eg

The code representing the country of Egypt.



Sv

The code representing the country of El Salvador.



Gq

The code representing the country of Equatorial Guinea.



Er

The code representing the country of Eritrea.



Ee

The code representing the country of Estonia.



Et

The code representing the country of Ethiopia.



Fk

The code representing the country of Falkland Islands (Malvinas).



Fo

The code representing the country of Faroe Islands.



Fj

The code representing the country of Fiji.



Fi

The code representing the country of Finland.



Fr

The code representing the country of France.



Gf

The code representing the country of French Guiana.



Pf

The code representing the country of French Polynesia.



Tf

The code representing the country of French Southern Territories.



Ga

The code representing the country of Gabon.



Gm

The code representing the country of Gambia.



Ge

The code representing the country of Georgia.



De

The code representing the country of Germany.



Gh

The code representing the country of Ghana.



Gi

The code representing the country of Gibraltar.



Gr

The code representing the country of Greece.



Gl

The code representing the country of Greenland.



Gd

The code representing the country of Grenada.



Gp

The code representing the country of Guadeloupe.



Gu

The code representing the country of Guam.



Gt

The code representing the country of Guatemala.



Gg

The code representing the country of Guernsey.



Gn

The code representing the country of Guinea.



Gw

The code representing the country of Guinea-Bissau.



Gy

The code representing the country of Guyana.



Ht

The code representing the country of Haiti.



Hm

The code representing the country of Heard Island and McDonald Islands.



Va

The code representing the country of Holy See (Vatican City State).



Hn

The code representing the country of Honduras.



Hk

The code representing the country of Hong Kong.



Hu

The code representing the country of Hungary.



Is

The code representing the country of Iceland.



In

The code representing the country of India.



Id

The code representing the country of Indonesia.



Ir

The code representing the country of Islamic Republic of Iran.



Iq

The code representing the country of Iraq.



Ie

The code representing the country of Ireland.



Im

The code representing the country of Isle of Man.



Il

The code representing the country of Israel.



It

The code representing the country of Italy.



Jm

The code representing the country of Jamaica.



Jp

The code representing the country of Japan.



Je

The code representing the country of Jersey.



Jo

The code representing the country of Jordan.



Kz

The code representing the country of Kazakhstan.



Ke

The code representing the country of Kenya.



Ki

The code representing the country of Kiribati.



Kp

The code representing the country of Democratic People’s Republic ofKorea.



Kr

The code representing the country of Republic of Korea.



Kw

The code representing the country of Kuwait.



Kg

The code representing the country of Kyrgyzstan.



La

The code representing the country of Lao People’s Democratic Republic.



Lv

The code representing the country of Latvia.



Lb

The code representing the country of Lebanon.



Ls

The code representing the country of Lesotho.



Lr

The code representing the country of Liberia.



Ly

The code representing the country of Libya.



Li

The code representing the country of Liechtenstein.



Lt

The code representing the country of Lithuania.



Lu

The code representing the country of Luxembourg.



Mo

The code representing the country of Macao.



Mk

The code representing the country of The Former Yugoslav Republic of Macedonia.



Mg

The code representing the country of Madagascar.



Mw

The code representing the country of Malawi.



My

The code representing the country of Malaysia.



Mv

The code representing the country of Maldives.



Ml

The code representing the country of Mali.



Mt

The code representing the country of Malta.



Mh

The code representing the country of Marshall Islands.



Mq

The code representing the country of Martinique.



Mr

The code representing the country of Mauritania.



Mu

The code representing the country of Mauritius.



Yt

The code representing the country of Mayotte.



Mx

The code representing the country of Mexico.



Fm

The code representing the country of Federated States ofMicronesia.



Md

The code representing the country of Republic of Moldova.



Mc

The code representing the country of Monaco.



Mn

The code representing the country of Mongolia.



Me

The code representing the country of Montenegro.



Ms

The code representing the country of Montserrat.



Ma

The code representing the country of Morocco.



Mz

The code representing the country of Mozambique.



Mm

The code representing the country of Myanmar.



Na

The code representing the country of Namibia.



Nr

The code representing the country of Nauru.



Np

The code representing the country of Nepal.



Nl

The code representing the country of Netherlands.



Nc

The code representing the country of New Caledonia.



Nz

The code representing the country of New Zealand.



Ni

The code representing the country of Nicaragua.



Ne

The code representing the country of Niger.



Ng

The code representing the country of Nigeria.



Nu

The code representing the country of Niue.



Nf

The code representing the country of Norfolk Island.



Mp

The code representing the country of Northern Mariana Islands.



No

The code representing the country of Norway.



Om

The code representing the country of Oman.



Pk

The code representing the country of Pakistan.



Pw

The code representing the country of Palau.



Ps

The code representing the country of State of Palestine.



Pa

The code representing the country of Panama.



Pg

The code representing the country of Papua New Guinea.



Py

The code representing the country of Paraguay.



Pe

The code representing the country of Peru.



Ph

The code representing the country of Philippines.



Pn

The code representing the country of Pitcairn.



Pl

The code representing the country of Poland.



Pt

The code representing the country of Portugal.



Pr

The code representing the country of Puerto Rico.



Qa

The code representing the country of Qatar.



Re

The code representing the country of Réunion.



Ro

The code representing the country of Romania.



Ru

The code representing the country of Russian Federation.



Rw

The code representing the country of Rwanda.



Bl

The code representing the country of Saint Barthélemy.



Sh

The code representing the country of Saint Helena Ascension and Tristan da Cunha.



Kn

The code representing the country of Saint Kitts and Nevis.



Lc

The code representing the country of Saint Lucia.



Mf

The code representing the country of Saint Martin (French part).



Pm

The code representing the country of Saint Pierre and Miquelon.



Vc

The code representing the country of Saint Vincent and the Grenadines.



Ws

The code representing the country of Samoa.



Sm

The code representing the country of San Marino.



St

The code representing the country of Sao Tome and Principe.



Sa

The code representing the country of Saudi Arabia.



Sn

The code representing the country of Senegal.



Rs

The code representing the country of Serbia.



Sc

The code representing the country of Seychelles.



Sl

The code representing the country of Sierra Leone.



Sg

The code representing the country of Singapore.



Sx

The code representing the country of Sint Maarten (Dutch part).



Sk

The code representing the country of Slovakia.



Si

The code representing the country of Slovenia.



Sb

The code representing the country of Solomon Islands.



So

The code representing the country of Somalia.



Za

The code representing the country of South Africa.



Gs

The code representing the country of South Georgia and the South Sandwich Islands.



Ss

The code representing the country of South Sudan.



Es

The code representing the country of Spain.



Lk

The code representing the country of Sri Lanka.



Sd

The code representing the country of Sudan.



Sr

The code representing the country of Suriname.



Sj

The code representing the country of Svalbard and Jan Mayen.



Sz

The code representing the country of Swaziland.



Se

The code representing the country of Sweden.



Ch

The code representing the country of Switzerland.



Sy

The code representing the country of Syrian Arab Republic.



Tw

The code representing the country of Taiwan, Province of China.



Tj

The code representing the country of Tajikistan.



Tz

The code representing the country of United Republic of Tanzania.



Th

The code representing the country of Thailand.



Tl

The code representing the country of Timor-Leste.



Tg

The code representing the country of Togo.



Tk

The code representing the country of Tokelau.



To

The code representing the country of Tonga.



Tt

The code representing the country of Trinidad and Tobago.



Tn

The code representing the country of Tunisia.



Tr

The code representing the country of Turkey.



Tm

The code representing the country of Turkmenistan.



Tc

The code representing the country of Turks and Caicos Islands.



Tv

The code representing the country of Tuvalu.



Ug

The code representing the country of Uganda.



Ua

The code representing the country of Ukraine.



Ae

The code representing the country of United Arab Emirates.



Gb

The code representing the country of United Kingdom.



Us

The code representing the country of United States.



Um

The code representing the country of United States Minor Outlying Islands.



Uy

The code representing the country of Uruguay.



Uz

The code representing the country of Uzbekistan.



Vu

The code representing the country of Vanuatu.



Ve

The code representing the country of Bolivarian Republic of Venezuela.



Vn

The code representing the country of Viet Nam.



Vg

The code representing the country of British Virgin Islands.



Vi

The code representing the country of U.S. Virgin Islands.



Wf

The code representing the country of Wallis and Futuna.



Eh

The code representing the country of Western Sahara.



Ye

The code representing the country of Yemen.



Zm

The code representing the country of Zambia.



Zw

The code representing the country of Zimbabwe.



Nn

The code representing a fake region for testing.