pub struct NodeToAddressesConnection {
pub count: i64,
pub entities: Vec<NodeAddress>,
}Expand description
A connection between a node and the addresses it has announced for itself on Lightning Network.
Fields
count: i64The total count of objects in this connection, using the current filters. It is different from the number of objects returned in the current page (in the entities field).
entities: Vec<NodeAddress>The addresses for the current page of this connection.