pub struct OutgoingPaymentAttempt {Show 13 fields
pub id: String,
pub created_at: DateTime<Utc>,
pub updated_at: DateTime<Utc>,
pub status: OutgoingPaymentAttemptStatus,
pub failure_code: Option<HtlcAttemptFailureCode>,
pub failure_source_index: Option<i64>,
pub attempted_at: DateTime<Utc>,
pub resolved_at: Option<DateTime<Utc>>,
pub amount: Option<CurrencyAmount>,
pub fees: Option<CurrencyAmount>,
pub outgoing_payment: EntityWrapper,
pub channel_snapshot: Option<EntityWrapper>,
pub typename: String,
}Expand description
This object represents an attempted Lightning Network payment sent from a Lightspark Node. You can retrieve this object to receive payment related information about any payment attempt sent from your Lightspark Node on the Lightning Network, including any potential reasons the payment may have failed.
Fields
id: StringThe unique identifier of this entity across all Lightspark systems. Should be treated as an opaque string.
created_at: DateTime<Utc>The date and time when the entity was first created.
updated_at: DateTime<Utc>The date and time when the entity was last updated.
status: OutgoingPaymentAttemptStatusThe status of an outgoing payment attempt.
failure_code: Option<HtlcAttemptFailureCode>If the payment attempt failed, then this contains the Bolt #4 failure code.
failure_source_index: Option<i64>If the payment attempt failed, then this contains the index of the hop at which the problem occurred.
attempted_at: DateTime<Utc>The date and time when the attempt was initiated.
resolved_at: Option<DateTime<Utc>>The time the outgoing payment attempt failed or succeeded.
amount: Option<CurrencyAmount>The total amount of funds required to complete a payment over this route. This value includes the cumulative fees for each hop. As a result, the attempt extended to the first-hop in the route will need to have at least this much value, otherwise the route will fail at an intermediate node due to an insufficient amount.
fees: Option<CurrencyAmount>The sum of the fees paid at each hop within the route of this attempt. In the case of a one-hop payment, this value will be zero as we don’t need to pay a fee to ourselves.
outgoing_payment: EntityWrapperThe outgoing payment for this attempt.
channel_snapshot: Option<EntityWrapper>The channel snapshot at the time the outgoing payment attempt was made.
typename: StringThe typename of the object
Implementations
Sourceimpl OutgoingPaymentAttempt
impl OutgoingPaymentAttempt
pub async fn get_hops( &self, requester: &impl GraphQLRequester, first: Option<i64>, after: Option<String>, ) -> Result<OutgoingPaymentAttemptToHopsConnection, Error>