pub struct Wallet {
pub id: String,
pub created_at: DateTime<Utc>,
pub updated_at: DateTime<Utc>,
pub last_login_at: Option<DateTime<Utc>>,
pub balances: Option<Balances>,
pub third_party_identifier: String,
pub account: Option<EntityWrapper>,
pub status: WalletStatus,
pub typename: String,
}Expand description
This object represents a Lightspark Wallet, tied to your Lightspark account. Wallets can be used to send or receive funds over the Lightning Network. You can retrieve this object to receive information about a specific wallet tied to your Lightspark account.
Fields
id: StringThe unique identifier of this entity across all Lightspark systems. Should be treated as an opaque string.
created_at: DateTime<Utc>The date and time when the entity was first created.
updated_at: DateTime<Utc>The date and time when the entity was last updated.
last_login_at: Option<DateTime<Utc>>The date and time when the wallet user last logged in.
balances: Option<Balances>The balances that describe the funds in this wallet.
third_party_identifier: StringThe unique identifier of this wallet, as provided by the Lightspark Customer during login.
account: Option<EntityWrapper>The account this wallet belongs to.
status: WalletStatusThe status of this wallet.
typename: StringThe typename of the object
Implementations
Sourceimpl Wallet
impl Wallet
pub async fn get_transactions( &self, requester: &impl GraphQLRequester, first: Option<i64>, after: Option<String>, created_after_date: Option<DateTime<Utc>>, created_before_date: Option<DateTime<Utc>>, statuses: Option<Vec<TransactionStatus>>, types: Option<Vec<TransactionType>>, ) -> Result<WalletToTransactionsConnection, Error>
pub async fn get_payment_requests( &self, requester: &impl GraphQLRequester, first: Option<i64>, after: Option<String>, created_after_date: Option<DateTime<Utc>>, created_before_date: Option<DateTime<Utc>>, ) -> Result<WalletToPaymentRequestsConnection, Error>
pub async fn get_total_amount_received( &self, requester: &impl GraphQLRequester, created_after_date: Option<DateTime<Utc>>, created_before_date: Option<DateTime<Utc>>, ) -> Result<CurrencyAmount, Error>
pub async fn get_withdrawal_requests( &self, requester: &impl GraphQLRequester, first: Option<i64>, after: Option<String>, statuses: Option<Vec<WithdrawalRequestStatus>>, created_after_date: Option<DateTime<Utc>>, created_before_date: Option<DateTime<Utc>>, ) -> Result<WalletToWithdrawalRequestsConnection, Error>
pub async fn get_total_amount_sent( &self, requester: &impl GraphQLRequester, created_after_date: Option<DateTime<Utc>>, created_before_date: Option<DateTime<Utc>>, ) -> Result<CurrencyAmount, Error>